benchlingcmd

package
v0.0.0-...-3409afb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 11, 2026 License: Apache-2.0 Imports: 17 Imported by: 1

README

Package cloudeng.io/webapi/clients/benchling/benchlingcmd

import cloudeng.io/webapi/clients/benchling/benchlingcmd

Package benchlingcmd provides support for building command line tools that access benchling.com

Functions

Func OptionsForEndpoint
func OptionsForEndpoint(cfg apicrawlcmd.Crawl[Service]) ([]operations.Option, error)

Types

Type Checkpoint
type Checkpoint struct {
	// Dates in rfc.3339 format.
	UsersDate   string `json:"users_date"`
	EntriesDate string `json:"entries_date"`
}
Type Command
type Command struct {
	// contains filtered or unexported fields
}

Çommand implements the command line operations available for protocols.io.

Functions
func NewCommand(ctx context.Context, config apicrawlcmd.Crawl[yaml.Node], resources apicrawlcmd.Resources) (*Command, error)

NewCommand returns a new Command instance for benchling API related commands.

Methods
func (c *Command) Crawl(ctx context.Context, _ CrawlFlags, entities ...string) error
func (c *Command) CreateIndexableDocuments(ctx context.Context, _ IndexFlags) error

CreateIndexableDocuments constructs the documents to be indexed from the various objects crawled from the benchling.com API.

Type Config
type Config apicrawlcmd.Crawl[Service]
Type CrawlFlags
type CrawlFlags struct{}
Type GetFlags
type GetFlags struct{}
Type IndexFlags
type IndexFlags struct{}
Type Service
type Service struct {
	ServiceURL       string `yaml:"service_url" cmd:"benchling service URL, typically https://altoslabs.benchling.com/api/v2/"`
	UsersPageSize    int    `yaml:"users_page_size" cmd:"number of users in each page of results, typically 50"`
	EntriesPageSize  int    `yaml:"entries_page_size" cmd:"number of entries in each page of results, typically 50"`
	FoldersPageSize  int    `yaml:"folders_page_size" cmd:"number of folders in each page of results, typically 50"`
	ProjectsPageSize int    `yaml:"projects_page_size" cmd:"number of projects in each page of results, typically 50"`
}
Methods
func (s Service) ListEntriesConfig() *benchlingsdk.ListEntriesParams
func (s Service) ListFoldersConfig() *benchlingsdk.ListFoldersParams
func (s Service) ListProjectsConfig() *benchlingsdk.ListProjectsParams
func (s Service) ListUsersConfig() *benchlingsdk.ListUsersParams

Documentation

Overview

Package benchlingcmd provides support for building command line tools that access benchling.com

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func OptionsForEndpoint

func OptionsForEndpoint(cfg apicrawlcmd.Crawl[Service]) ([]operations.Option, error)

Types

type Checkpoint

type Checkpoint struct {
	// Dates in rfc.3339 format.
	UsersDate   string `json:"users_date"`
	EntriesDate string `json:"entries_date"`
}

type Command

type Command struct {
	// contains filtered or unexported fields
}

Çommand implements the command line operations available for protocols.io.

func NewCommand

func NewCommand(ctx context.Context, config apicrawlcmd.Crawl[yaml.Node], resources apicrawlcmd.Resources) (*Command, error)

NewCommand returns a new Command instance for benchling API related commands.

func (*Command) Crawl

func (c *Command) Crawl(ctx context.Context, _ CrawlFlags, entities ...string) error

func (*Command) CreateIndexableDocuments

func (c *Command) CreateIndexableDocuments(ctx context.Context, _ IndexFlags) error

CreateIndexableDocuments constructs the documents to be indexed from the various objects crawled from the benchling.com API.

type Config

type Config apicrawlcmd.Crawl[Service]

type CrawlFlags

type CrawlFlags struct{}

type GetFlags

type GetFlags struct{}

type IndexFlags

type IndexFlags struct{}

type Service

type Service struct {
	ServiceURL       string `yaml:"service_url" cmd:"benchling service URL, typically https://altoslabs.benchling.com/api/v2/"`
	UsersPageSize    int    `yaml:"users_page_size" cmd:"number of users in each page of results, typically 50"`
	EntriesPageSize  int    `yaml:"entries_page_size" cmd:"number of entries in each page of results, typically 50"`
	FoldersPageSize  int    `yaml:"folders_page_size" cmd:"number of folders in each page of results, typically 50"`
	ProjectsPageSize int    `yaml:"projects_page_size" cmd:"number of projects in each page of results, typically 50"`
}

func (Service) ListEntriesConfig

func (s Service) ListEntriesConfig() *benchlingsdk.ListEntriesParams

func (Service) ListFoldersConfig

func (s Service) ListFoldersConfig() *benchlingsdk.ListFoldersParams

func (Service) ListProjectsConfig

func (s Service) ListProjectsConfig() *benchlingsdk.ListProjectsParams

func (Service) ListUsersConfig

func (s Service) ListUsersConfig() *benchlingsdk.ListUsersParams

Jump to