papersappcmd

package
v0.0.0-...-2694e12 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 8, 2026 License: Apache-2.0 Imports: 16 Imported by: 1

README

Package cloudeng.io/webapi/clients/papersapp/papersappcmd

import cloudeng.io/webapi/clients/papersapp/papersappcmd

Functions

Func OptionsForEndpoint
func OptionsForEndpoint(cfg apicrawlcmd.Crawl[Service]) ([]operations.Option, error)

Types

Type Command
type Command struct {
	// contains filtered or unexported fields
}

Çommand implements the command line operations available for papersapp.com.

Functions
func NewCommand(ctx context.Context, config apicrawlcmd.Crawl[yaml.Node], resources apicrawlcmd.Resources) (*Command, error)

NewCommand returns a new Command instance for readcube/papersapp API related commands.

Methods
func (c *Command) Crawl(ctx context.Context, _ *CrawlFlags) error
func (c *Command) ScanDownloaded(ctx context.Context, _ *ScanFlags) error
Type CrawlFlags
type CrawlFlags struct{}
Type ScanFlags
type ScanFlags struct{}
Type Service
type Service struct {
	ServiceURL        string `yaml:"service_url" cmd:"papersapp service URL, typically https://api.papers.ai"`
	RefreshTokenURL   string `yaml:"refresh_token_url" cmd:"papersapp refresh token URL, typically https://api.papers.ai/oauth/token"`
	ListItemsPageSize int    `yaml:"list_items_page_size" cmd:"number of items in each page of results, typically 50"`
}

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func OptionsForEndpoint

func OptionsForEndpoint(cfg apicrawlcmd.Crawl[Service]) ([]operations.Option, error)

Types

type Command

type Command struct {
	// contains filtered or unexported fields
}

Çommand implements the command line operations available for papersapp.com.

func NewCommand

func NewCommand(ctx context.Context, config apicrawlcmd.Crawl[yaml.Node], resources apicrawlcmd.Resources) (*Command, error)

NewCommand returns a new Command instance for readcube/papersapp API related commands.

func (*Command) Crawl

func (c *Command) Crawl(ctx context.Context, _ *CrawlFlags) error

func (*Command) ScanDownloaded

func (c *Command) ScanDownloaded(ctx context.Context, _ *ScanFlags) error

type CrawlFlags

type CrawlFlags struct{}

type ScanFlags

type ScanFlags struct{}

type Service

type Service struct {
	ServiceURL        string `yaml:"service_url" cmd:"papersapp service URL, typically https://api.papers.ai"`
	RefreshTokenURL   string `yaml:"refresh_token_url" cmd:"papersapp refresh token URL, typically https://api.papers.ai/oauth/token"`
	ListItemsPageSize int    `yaml:"list_items_page_size" cmd:"number of items in each page of results, typically 50"`
}

Jump to